@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.php.
  *
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2014 Horde LLC
  * @license   http://www.horde.org/licenses/gpl.php
  * @package   Passwd
  */
@@ -16,7 +16,7 @@
  *
  * @author    Ralf Lang <lang@b1-systems.de>
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2014 Horde LLC
  * @license   http://www.horde.org/licenses/gpl.php
  * @package   Passwd
  *
@@ -119,7 +119,8 @@ class Passwd_Factory_Driver extends Horde_Core_Factory_Base
                             $params = $backend['params'];
                             unset($params['table'], $params['user_col'],
                                   $params['pass_col'], $params['encryption'],
-                                  $params['show_encryption']);
+                                  $params['show_encryption'],
+                                  $params['query_lookup'], $params['query_modify']);
                             $backend['params']['db'] = $this->_injector
                                 ->getInstance('Horde_Core_Factory_Db')
                                 ->create('passwd', $params);
